@@ -297,6 +297,7 @@ from bitmovin_api_sdk.models.dolby_digital_preprocessing import DolbyDigitalPrep
 from bitmovin_api_sdk.models.dolby_digital_surround_mix_level import DolbyDigitalSurroundMixLevel
 from bitmovin_api_sdk.models.dolby_digital_surround_mode import DolbyDigitalSurroundMode
 from bitmovin_api_sdk.models.dolby_digital_three_db_attenuation import DolbyDigitalThreeDbAttenuation
+from bitmovin_api_sdk.models.dolby_vision_input_stream import DolbyVisionInputStream
 from bitmovin_api_sdk.models.dolby_vision_metadata import DolbyVisionMetadata
 from bitmovin_api_sdk.models.dolby_vision_metadata_ingest_input_stream import DolbyVisionMetadataIngestInputStream
 from bitmovin_api_sdk.models.dolby_vision_metadata_source import DolbyVisionMetadataSource
@@ -380,6 +381,7 @@ from bitmovin_api_sdk.models.h264_picture_timing_trimming_input_stream import H2
 from bitmovin_api_sdk.models.h264_sub_me import H264SubMe
 from bitmovin_api_sdk.models.h264_trellis import H264Trellis
 from bitmovin_api_sdk.models.h264_video_configuration import H264VideoConfiguration
+from bitmovin_api_sdk.models.h265_dynamic_range_format import H265DynamicRangeFormat
 from bitmovin_api_sdk.models.h265_per_title_configuration import H265PerTitleConfiguration
 from bitmovin_api_sdk.models.h265_video_configuration import H265VideoConfiguration
 from bitmovin_api_sdk.models.he_aac_v1_audio_configuration import HeAacV1AudioConfiguration
