@@ -13,18 +13,18 @@ import six
 class WebVttConfiguration(SubtitleConfiguration):
     @poscheck_model
     def __init__(self,
+                 id_=None,
                  name=None,
                  description=None,
                  created_at=None,
                  modified_at=None,
                  custom_data=None,
-                 id_=None,
                  append_optional_zero_hour=None,
                  ignore_region=None,
                  cue_identifier_policy=None,
                  styling=None):
-        # type: (string_types, string_types, datetime, datetime, dict, string_types, bool, bool, WebVttCueIdentifierPolicy, WebVttStyling) -> None
-        super(WebVttConfiguration, self).__init__(name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, id_=id_)
+        # type: (string_types, string_types, string_types, datetime, datetime, dict, bool, bool, WebVttCueIdentifierPolicy, WebVttStyling) -> None
+        super(WebVttConfiguration, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)
 
         self._append_optional_zero_hour = None
         self._ignore_region = None
